# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"say_hello": "00_core.ipynb",
         "generate_db": "00_core.ipynb",
         "insert_row": "00_core.ipynb",
         "Card": "01_card.ipynb",
         "Deck": "01_card.ipynb",
         "Hand": "01_card.ipynb",
         "find_defining_class": "01_card.ipynb"}

modules = ["core.py",
           "card.py"]

doc_url = "https://lukexyz.github.io/prodb/"

git_url = "https://github.com/lukexyz/prodb/tree/master/"

def custom_doc_links(name): return None
